=========
changeLog
=========

All notable changes to this project will be documented in this file.

***************
Current changes
***************

`Unreleased`_
=============

Added
-----

Changed
-------

Fixed
-----

Deprecated
----------

Removed
-------

Security
--------

`v0.1'_
=======

* First working release.

.. _Unreleased: https://github.com/miurahr/picast/compare/v0.1...HEAD
.. _v0.1: https://github.com/miurahr/picast/releases/tag/v0.1
